@@ -25,13 +25,14 @@
 | Fixed bug in ExecuteSys() when monitor dies      | J.L. Bezemer     |040411|
 | Applied Coherent patches                         | J.L. Bezemer     |020112|
 | Applied Coherent patch WRITETEXT                 | J.L. Bezemer     |290312|
+| Added Francois Perrad LINT patches               | Francois Perrad  |221016|
 +--------------------------------------------------+------------------+------+
 |REMARKS                                           |    Programmer    | Date |
 +--------------------------------------------------+------------------+------+
 | Demonstration for 4th toolkit                    | J.L. Bezemer     |010207|
 +--------------------------------------------------+------------------+------+
 
-  Copyright (C) 2007, 2012 J.L. Bezemer
+  Copyright (C) 2007, 2016 J.L. Bezemer
 
   This file is part of 4tH
 
@@ -62,7 +63,7 @@
 #define MAXDUMP     16                 /* no. lines on decompile */
 #define MAXJOBS     64                 /* maximum number of jobs */
 #define INIT         0                 /* first job */
-#define KILLED      -1                 /* not a valid task */
+#define KILLED    (-1)                 /* not a valid task */
                                        /* -TASK STATUS- */
 #define SSLEEP 0                       /* sleeping task */
 #define SNORM  0                       /* normal task */
@@ -115,8 +116,8 @@ typedef struct {
    int    Id;                          /* process id */
 } Job;
 
-Job Process [MAXJOBS];                 /* job table */
-int ToS = INIT;                        /* top of job stack */
+static Job Process [MAXJOBS];          /* job table */
+static int ToS = INIT;                 /* top of job stack */
 
 /*
 This function gets a value from the 4tH user stack
@@ -131,7 +132,7 @@ This function gets a value from the 4tH user stack
 {
   cell *sp = MK_CP (Object, stack);
 
-  return (*sp > stack ? (int) *(MK_CP (Object, (*sp)--)) : INT_MIN);
+  return ((*sp > stack) ? (int) *(MK_CP (Object, (*sp)--)) : INT_MIN);
 }
 
 
@@ -318,7 +319,7 @@ the 4tH user stack.
       {                                /* if there is a value on the stack */
         name = (char*) MK_UP (obj, a); /* make a pointer to the name */
         a = AddTask ((*loader) (name), name, SUSER);
-        to_4th (obj, stk, a < ToS ? Process [a].Id : KILLED);
+        to_4th (obj, stk, (a < ToS) ? Process [a].Id : KILLED);
       }                                /* load job and leave pid on stack */
    else to_4th (obj, stk, KILLED);     /* leave "killed" pid on error */
 }
@@ -365,7 +366,7 @@ with an address issued by the user.
   if (CHECK (a = from_4th (obj, stk)))  /* get pid */
      if (CHECK (b = from_4th (obj, stk)))
         if ((b = ToJob (b)) < ToS)      /* convert, if valid decompile */
-           dump_4th (Process [b].Job, stdout, a, a + MAXDUMP);
+           (void) dump_4th (Process [b].Job, stdout, a, a + MAXDUMP);
 }
 
 
@@ -416,7 +417,7 @@ It uses the 4tH user stack to fetch its parameters.
     case (JSTAT):  if (CHECK (a = from_4th (obj, stk)))
                       {
                         a = ToJob (a); /* convert pid to job */
-                        to_4th (obj, stk, a < ToS ?
+                        to_4th (obj, stk, (a < ToS) ?
                                 Process [a].Stat & SAWAKE : SKILL);
                       }                /* assume bad job is killed */
                    break;              /* return the status */
@@ -512,7 +513,7 @@ there are no jobs (awake) anymore.
       if (Process [job].Stat & SAWAKE)
          {                             /* if awake job has been found */
            awake++;                    /* register awake job */
-           job = Process [job].Stat & SSYST ?
+           job = (Process [job].Stat & SSYST) ?
                  ExecuteSys  (job, argn, args) : ExecuteUser (job);
          }                             /* execute either system or user */
       else job++;                      /* sleeping job, so skip */
