@@ -59,7 +59,7 @@ static unit EmbeddedHX [] = {
   '\x12', '\x2a', '\x1e', '\x4d', '\x47', '\x04', '\xa7', '\x00', '\x2c', 
   '\x29', '\x10', '\x41', '\x1d', '\x04', '\xf1', '\x00', '\x12', '\x12', 
   '\x1e', '\x15', '\x41', '\x1d', '\x04', '\x06', '\x01', '\x58', '\x02', 
-  '\x05', '\x28', '\x11', '\x1e', '\x32', '\x11', '\x18', '\x11', '\x1c', 
+  '\x05', '\x28', '\x11', '\x1e', '\x32', '\x09', '\x18', '\x11', '\x1c', 
   '\x04', '\x03', '\x01', '\x14', '\x5e', '\x02', '\x05', '\x11', '\x2c', 
   '\x1c', '\x04', '\x03', '\x01', '\x14', '\x2a', '\x0b', '\x1d', '\x04', 
   '\xf4', '\x00', '\x29', '\x14', '\x41', '\x32', '\x09', '\x58', '\x02', 
@@ -109,7 +109,7 @@ static unit EmbeddedHX [] = {
   '\x11', '\x47', '\x04', '\xc7', '\x01', '\x32', '\x11', '\x13', '\x3e', 
   '\x41', '\x1d', '\x04', '\xde', '\x01', '\x11', '\x07', '\x10', '\x0c', 
   '\x41', '\x00', '\x02', '\x07', '\x5b', '\x10', '\x00', '\x02', '\x0a', 
-  '\x5b', '\x11', '\x5b', '\x11', '\x1d', '\x04', '\xf8', '\x01', '\x32', 
+  '\x5b', '\x11', '\x5b', '\x09', '\x1d', '\x04', '\xf8', '\x01', '\x32', 
   '\x04', '\xdf', '\x01', '\x32', '\x02', '\x02', '\x32', '\x04', '\xe0', 
   '\x00', '\x47', '\x04', '\xf2', '\x00', '\x1c', '\x04', '\xf0', '\x01', 
   '\x33', '\x10', '\x1e', '\x28', '\x13', '\x29', '\x0b', '\x1d', '\x04', 
@@ -223,7 +223,7 @@ static unit EmbeddedHX [] = {
   '\xcd', '\x02', '\x00', '\x04', '\xc7', '\x00', '\x5b', '\x04', '\xbb', 
   '\x02', '\x00', '\x04', '\xcc', '\x00', '\x5b', '\x04', '\xb4', '\x02', 
   '\x00', '\x04', '\xd1', '\x00', '\x5b', '\x04', '\xb7', '\x02', '\x00', 
-  '\x04', '\xd6', '\x00', '\x5b', '\x04', '\xd4', '\x02', '\x5b', '\x11', 
+  '\x04', '\xd6', '\x00', '\x5b', '\x04', '\xd4', '\x02', '\x5b', '\x09', 
   '\x32', '\x04', '\x06', '\x03', '\x58', '\x02', '\x07', '\x1d', '\x04', 
   '\x6a', '\x03', '\x45', '\x02', '\x08', '\x11', '\x47', '\x04', '\xc3', 
   '\x01', '\x32', '\x02', '\x07', '\x08', '\x47', '\x04', '\x23', '\x02', 
@@ -255,5 +255,5 @@ static unit EmbeddedHX [] = {
   '\x69', '\x6c', '\x6c', '\x00', '\x68', '\x61', '\x6c', '\x74', '\x00', 
   '\x62', '\x6f', '\x6f', '\x74', '\x00', '\x74', '\x61', '\x73', '\x6b', 
   '\x00', '\x74', '\x61', '\x73', '\x6b', '\x73', '\x00', '\x4f', '\x4b', 
-  '\x00', '\x4f', '\x6f', '\x70', '\x73', '\x20', '\x00', '\xb5'
+  '\x00', '\x4f', '\x6f', '\x70', '\x73', '\x20', '\x00', '\xad'
 };
